@@ -218,6 +218,22 @@ class TestBuilder(TestCase):
         found_resource = [x for x in namespace.resources if x.urls[0] == "/<int:id>"]
         self.assertEqual(1, len(found_resource))
 
+    def test_building_resource_with_wrapper_applies_wrapper_to_methods(self, *_):
+        # Arrange
+        test_class = TestBaseEntity()
+        namespace, model = buil_model(test_class)
+        
+        # Act
+        build_resource(test_class, namespace, model, model, custom_wrapper=lambda f: (lambda *a, **k: f(*a, **k)))
+        
+        # Assert
+        get_all_resource = [x for x in namespace.resources if x.urls[0] == "/"][0]
+        get_by_id_resource = [x for x in namespace.resources if x.urls[0] == "/<int:id>"][0]
+        self.assertTrue(hasattr(get_all_resource.resource, "get"))
+        self.assertTrue(hasattr(get_by_id_resource.resource, "get"))
+        self.assertTrue(callable(get_all_resource.resource.get))
+        self.assertTrue(callable(get_by_id_resource.resource.get))
+
     def setup_namespace(self, name: str):
         app = Flask(__name__)
         app.testing = True
@@ -258,6 +274,25 @@ class TestBuilder(TestCase):
         # Assert
         self.assertEqual(200, response.status_code)
 
+    def test_getting_all_data_sorted_by_key_returns_ok(self, *_):
+        # Arrange
+        ns_name = 'testentity'
+        app, namespace, mock_entity = self.setup_namespace(ns_name)
+        mock_entity.get_all.return_value = [
+            TestBaseEntity(id=2, name="B"),
+            TestBaseEntity(id=1, name="A"),
+            TestBaseEntity(id=3, name="C"),
+        ]
+        build_resource(mock_entity, namespace, Model(ns_name), Model(ns_name), sort_by="id")
+
+        # Act
+        with app.test_client() as client:
+            response = client.get(f'/{ns_name}/')
+
+        # Assert
+        self.assertEqual(200, response.status_code)
+        self.assertEqual(3, len(response.json)) # type: ignore
+
     def test_posting_returns_not_found_when_resource_is_not_defined(self, *_):
         # Arrange
         ns_name = 'testentity'
